=== modified file 'libdrizzle-2.0/column.cc'
--- libdrizzle-2.0/column.cc	2011-11-18 02:03:41 +0000
+++ libdrizzle-2.0/column.cc	2011-11-18 16:11:02 +0000
@@ -361,7 +361,13 @@
 
   if (column == NULL)
   {
-    column= new (std::nothrow)drizzle_column_st;
+    column= new (std::nothrow) drizzle_column_st;
+
+    if (column == NULL)
+    {
+      return NULL;
+    }
+
     column->result= result;
     /* SET BELOW: column->next */
     column->prev= NULL;
@@ -683,7 +689,12 @@
       return DRIZZLE_RETURN_OK;
     }
 
-    result->column_buffer= new drizzle_column_st[result->column_count];
+    result->column_buffer= new (std::nothrow) drizzle_column_st[result->column_count];
+
+    if (result->column_buffer == NULL)
+    {
+      return DRIZZLE_RETURN_MEMORY;
+    }
   }
 
   /* No while body, just keep calling to buffer columns. */

=== modified file 'libdrizzle-2.0/column.h'
--- libdrizzle-2.0/column.h	2011-11-18 02:03:41 +0000
+++ libdrizzle-2.0/column.h	2011-11-18 16:11:02 +0000
@@ -148,8 +148,7 @@
  * Get the Drizzle type of a column.
  */
 DRIZZLE_API
-drizzle_column_type_drizzle_t
-drizzle_column_type_drizzle(drizzle_column_st *column);
+drizzle_column_type_drizzle_t drizzle_column_type_drizzle(drizzle_column_st *column);
 
 /**
  * Get flags for a column.

=== modified file 'libdrizzle-2.0/conn.cc'
--- libdrizzle-2.0/conn.cc	2011-11-18 02:03:41 +0000
+++ libdrizzle-2.0/conn.cc	2011-11-18 16:11:02 +0000
@@ -586,13 +586,13 @@
     {
       drizzle_set_error(con->drizzle, "drizzle_command_write", "connection not ready");
       *ret_ptr= DRIZZLE_RETURN_NOT_READY;
-      return result;
+      return NULL;
     }
 
     *ret_ptr= drizzle_con_connect(con);
     if (*ret_ptr != DRIZZLE_RETURN_OK)
     {
-      return result;
+      return NULL;
     }
   }
 
@@ -610,7 +610,7 @@
         {
           drizzle_set_error(con->drizzle, "drizzle_command_write", "result struct already in use");
           *ret_ptr= DRIZZLE_RETURN_INTERNAL_ERROR;
-          return result;
+          return NULL;
         }
       }
 
@@ -697,8 +697,7 @@
   con->backlog= backlog;
 }
 
-void drizzle_con_set_protocol_version(drizzle_con_st *con,
-                                      uint8_t protocol_version)
+void drizzle_con_set_protocol_version(drizzle_con_st *con, uint8_t protocol_version)
 {
   if (con == NULL)
   {
@@ -897,7 +896,14 @@
 
   if (con->command_buffer == NULL)
   {
-    con->command_buffer= new uint8_t[(*total) + 1];
+    con->command_buffer= new (std::nothrow) uint8_t[(*total) + 1];
+
+    if (con->command_buffer == NULL)
+    {
+      *total= 0;
+      *ret_ptr= DRIZZLE_RETURN_MEMORY;
+      return NULL;
+    }
   }
 
   memcpy(con->command_buffer + offset, command_data, size);
@@ -1168,12 +1174,16 @@
     if (ret != DRIZZLE_RETURN_OK)
       return ret;
 
-    if (con->drizzle->options & DRIZZLE_NON_BLOCKING)
+    if (con->drizzle->options.is_non_blocking)
+    {
       return DRIZZLE_RETURN_IO_WAIT;
+    }
 
     ret= drizzle_con_wait(con->drizzle);
     if (ret != DRIZZLE_RETURN_OK)
+    {
       return ret;
+    }
   }
 }
 
@@ -1192,7 +1202,7 @@
   }
 
   if ((con->revents & POLLIN) == 0 &&
-      (con->drizzle->options & DRIZZLE_NON_BLOCKING))
+      (con->drizzle->options.is_non_blocking))
   {
     /* non-blocking mode: return IO_WAIT instead of attempting to read. This
      * avoids reading immediately after writing a command, which typically
@@ -1265,12 +1275,16 @@
         if (ret != DRIZZLE_RETURN_OK)
           return ret;
 
-        if (con->drizzle->options & DRIZZLE_NON_BLOCKING)
+        if (con->drizzle->options.is_non_blocking)
+        {
           return DRIZZLE_RETURN_IO_WAIT;
+        }
 
         ret= drizzle_con_wait(con->drizzle);
         if (ret != DRIZZLE_RETURN_OK)
+        {
           return ret;
+        }
 
         continue;
       }
@@ -1368,19 +1382,27 @@
       {
         ret= drizzle_con_set_events(con, POLLOUT);
         if (ret != DRIZZLE_RETURN_OK)
+        {
           return ret;
+        }
 
-        if (con->drizzle->options & DRIZZLE_NON_BLOCKING)
+        if (con->drizzle->options.is_non_blocking)
+        {
           return DRIZZLE_RETURN_IO_WAIT;
+        }
 
         ret= drizzle_con_wait(con->drizzle);
         if (ret != DRIZZLE_RETURN_OK)
+        {
           return ret;
+        }
 
         continue;
       }
       else if (errno == EINTR)
+      {
         continue;
+      }
       else if (errno == EPIPE || errno == ECONNRESET)
       {
         drizzle_set_error(con->drizzle, "drizzle_state_write",

=== modified file 'libdrizzle-2.0/constants.h'
--- libdrizzle-2.0/constants.h	2011-11-18 02:03:41 +0000
+++ libdrizzle-2.0/constants.h	2011-11-18 16:11:02 +0000
@@ -197,8 +197,8 @@
  */
 enum drizzle_con_socket_t
 {
-  DRIZZLE_CON_SOCKET_TCP= 0,
-  DRIZZLE_CON_SOCKET_UDS= (1 << 0)
+  DRIZZLE_CON_SOCKET_TCP,
+  DRIZZLE_CON_SOCKET_UDS
 };
 
 #ifndef __cplusplus
@@ -526,6 +526,7 @@
 class drizzle_result_st;
 class drizzle_column_st;
 #endif
+
 typedef char drizzle_field_t_type;
 typedef drizzle_field_t_type *drizzle_field_t;
 typedef drizzle_field_t drizzle_row_t_type;
@@ -542,15 +543,11 @@
 #endif
 
 /* Function types. */
-typedef void (drizzle_context_free_fn)(drizzle_st *drizzle,
-                                       void *context);
-typedef void (drizzle_log_fn)(const char *line, drizzle_verbose_t verbose,
-                              void *context);
+typedef void (drizzle_context_free_fn)(drizzle_st *drizzle, void *context);
+typedef void (drizzle_log_fn)(const char *line, drizzle_verbose_t verbose, void *context);
 typedef drizzle_return_t (drizzle_state_fn)(drizzle_con_st *con);
-typedef void (drizzle_con_context_free_fn)(drizzle_con_st *con,
-                                           void *context);
-typedef void (drizzle_query_context_free_fn)(drizzle_query_st *query,
-                                             void *context);
+typedef void (drizzle_con_context_free_fn)(drizzle_con_st *con, void *context);
+typedef void (drizzle_query_context_free_fn)(drizzle_query_st *query, void *context);
 /**
  * Custom function to register or deregister interest in file descriptor
  * events. See drizzle_set_event_watch_fn().

=== modified file 'libdrizzle-2.0/drizzle.cc'
--- libdrizzle-2.0/drizzle.cc	2011-11-18 02:03:41 +0000
+++ libdrizzle-2.0/drizzle.cc	2011-11-18 16:11:02 +0000
@@ -79,7 +79,9 @@
 const char *drizzle_verbose_name(drizzle_verbose_t verbose)
 {
   if (verbose >= DRIZZLE_VERBOSE_MAX)
+  {
     return "UNKNOWN";
+  }
 
   return _verbose_name[verbose];
 }
@@ -101,15 +103,19 @@
 
   if (drizzle == NULL)
   {
-    drizzle= new drizzle_st;
-    drizzle->options= DRIZZLE_ALLOCATED;
+    drizzle= new (std::nothrow) drizzle_st;
+
+    if (drizzle == NULL)
+    {
+      return NULL;
+    }
+    drizzle->options.is_allocated= true;
   }
-  else
-    drizzle->options= DRIZZLE_NONE;
 
   /* @todo remove this default free flag with new API. */
-  drizzle->options|= DRIZZLE_FREE_OBJECTS;
+  drizzle->options.is_free_objects= true;
   drizzle->error_code= 0;
+
   /* drizzle->options set above */
   drizzle->verbose= DRIZZLE_VERBOSE_NEVER;
   drizzle->con_count= 0;
@@ -138,9 +144,13 @@
 {
   drizzle= drizzle_create(drizzle);
   if (drizzle == NULL)
+  {
     return NULL;
+  }
 
-  drizzle->options|= (from->options & ~DRIZZLE_ALLOCATED);
+  bool cache_state= drizzle->options.is_allocated;
+  drizzle->options= from->options;
+  drizzle->options.is_allocated= cache_state;
 
   for (drizzle_con_st* con= from->con_list; con != NULL; con= con->next)
   {
@@ -157,14 +167,16 @@
 void drizzle_free(drizzle_st *drizzle)
 {
   if (drizzle->context != NULL && drizzle->context_free_fn != NULL)
+  {
     drizzle->context_free_fn(drizzle, drizzle->context);
+  }
 
-  if (drizzle->options & DRIZZLE_FREE_OBJECTS)
+  if (drizzle->options.is_free_objects)
   {
     drizzle_con_free_all(drizzle);
     drizzle_query_free_all(drizzle);
   }
-  else if (drizzle->options & DRIZZLE_ASSERT_DANGLING)
+  else if (drizzle->options.is_assert_dangling)
   {
     assert(drizzle->con_list == NULL);
     assert(drizzle->query_list == NULL);
@@ -172,8 +184,10 @@
 
   free(drizzle->pfds);
 
-  if (drizzle->options & DRIZZLE_ALLOCATED)
+  if (drizzle->options.is_allocated)
+  {
     delete drizzle;
+  }
 #if defined(_WIN32)
   /* if it is MS windows, invoke WSACleanup() at the end*/
   WSACleanup();
@@ -200,24 +214,17 @@
   return drizzle->sqlstate;
 }
 
-int drizzle_options(const drizzle_st *drizzle)
-{
-  return drizzle->options;
-}
-
-void drizzle_set_options(drizzle_st *drizzle, int options)
-{
-  drizzle->options= options;
-}
-
-void drizzle_add_options(drizzle_st *drizzle, int options)
-{
-  drizzle->options|= options;
-}
-
-void drizzle_remove_options(drizzle_st *drizzle, drizzle_options_t options)
-{
-  drizzle->options&= ~options;
+int drizzle_options(const drizzle_st *)
+{
+  return 0;
+}
+
+void drizzle_set_options(drizzle_st *, int)
+{
+}
+
+void drizzle_add_options(drizzle_st *, int)
+{
 }
 
 void *drizzle_context(const drizzle_st *drizzle)
@@ -275,14 +282,17 @@
 {
   if (con == NULL)
   {
-    con= new drizzle_con_st;
+    con= new (std::nothrow) drizzle_con_st;
     con->options= DRIZZLE_CON_ALLOCATED;
   }
   else
+  {
     con->options= 0;
+  }
 
   if (drizzle->con_list != NULL)
     drizzle->con_list->prev= con;
+
   con->next= drizzle->con_list;
   con->prev= NULL;
   drizzle->con_list= con;
@@ -341,7 +351,9 @@
 {
   con= drizzle_con_create(drizzle, con);
   if (con == NULL)
+  {
     return NULL;
+  }
 
   /* Clear "operational" options such as IO status. */
   con->options|= (from->options & ~(DRIZZLE_CON_ALLOCATED|DRIZZLE_CON_READY|
@@ -369,34 +381,52 @@
 void drizzle_con_free(drizzle_con_st *con)
 {
   if (con->context != NULL && con->context_free_fn != NULL)
+  {
     con->context_free_fn(con, con->context);
+  }
 
-  if (con->drizzle->options & DRIZZLE_FREE_OBJECTS)
+  if (con->drizzle->options.is_free_objects)
+  {
     drizzle_result_free_all(con);
-  else if (con->drizzle->options & DRIZZLE_ASSERT_DANGLING)
+  }
+  else if (con->drizzle->options.is_assert_dangling)
+  {
     assert(con->result_list == NULL);
+  }
 
   if (con->fd != -1)
+  {
     drizzle_con_close(con);
+  }
 
   drizzle_con_reset_addrinfo(con);
 
   if (con->drizzle->con_list == con)
+  {
     con->drizzle->con_list= con->next;
+  }
   if (con->prev != NULL)
+  {
     con->prev->next= con->next;
+  }
   if (con->next != NULL)
+  {
     con->next->prev= con->prev;
+  }
   con->drizzle->con_count--;
 
   if (con->options & DRIZZLE_CON_ALLOCATED)
+  {
     delete con;
+  }
 }
 
 void drizzle_con_free_all(drizzle_st *drizzle)
 {
   while (drizzle->con_list != NULL)
+  {
     drizzle_con_free(drizzle->con_list);
+  }
 }
 
 drizzle_return_t drizzle_con_wait(drizzle_st *drizzle)
@@ -418,7 +448,9 @@
     drizzle->pfds_size= drizzle->con_count;
   }
   else
+  {
     pfds= drizzle->pfds;
+  }
 
   uint32_t x= 0;
   for (drizzle_con_st* con= drizzle->con_list; con != NULL; con= con->next)
@@ -528,7 +560,9 @@
 {
   con= drizzle_con_create(drizzle, con);
   if (con == NULL)
+  {
     return NULL;
+  }
 
   drizzle_con_set_tcp(con, host, port);
   drizzle_con_set_auth(con, user, password);
@@ -545,7 +579,9 @@
 {
   con= drizzle_con_create(drizzle, con);
   if (con == NULL)
+  {
     return NULL;
+  }
 
   drizzle_con_set_uds(con, uds);
   drizzle_con_set_auth(con, user, password);
@@ -567,7 +603,9 @@
 {
   con= drizzle_con_create(drizzle, con);
   if (con == NULL)
+  {
     return NULL;
+  }
 
   drizzle_con_set_tcp(con, host, port);
   drizzle_con_set_backlog(con, backlog);
@@ -583,7 +621,9 @@
 {
   con= drizzle_con_create(drizzle, con);
   if (con == NULL)
+  {
     return NULL;
+  }
 
   drizzle_con_set_uds(con, uds);
   drizzle_con_set_backlog(con, backlog);
@@ -623,7 +663,7 @@
       return con;
     }
 
-    if (drizzle->options & DRIZZLE_NON_BLOCKING)
+    if (drizzle->options.is_non_blocking)
     {
       *ret_ptr= DRIZZLE_RETURN_IO_WAIT;
       return NULL;
@@ -662,16 +702,29 @@
   int written= vsnprintf(ptr, DRIZZLE_MAX_ERROR_SIZE - size, format, args);
   va_end(args);
 
-  if (written < 0) size= DRIZZLE_MAX_ERROR_SIZE;
-  else size+= written;
+  if (written < 0) 
+  {
+    size= DRIZZLE_MAX_ERROR_SIZE;
+  }
+  else 
+  {
+    size+= written;
+  }
+
   if (size >= DRIZZLE_MAX_ERROR_SIZE)
+  {
     size= DRIZZLE_MAX_ERROR_SIZE - 1;
+  }
   log_buffer[size]= 0;
 
   if (drizzle->log_fn == NULL)
+  {
     memcpy(drizzle->last_error, log_buffer, size + 1);
+  }
   else
+  {
     drizzle->log_fn(log_buffer, DRIZZLE_VERBOSE_ERROR, drizzle->log_context);
+  }
 }
 
 void drizzle_log(drizzle_st *drizzle, drizzle_verbose_t verbose,

=== modified file 'libdrizzle-2.0/drizzle.h'
--- libdrizzle-2.0/drizzle.h	2011-11-07 15:04:16 +0000
+++ libdrizzle-2.0/drizzle.h	2011-11-18 16:11:02 +0000
@@ -251,7 +251,7 @@
  * @param[in] options Available options for drizzle structure to remove.
  */
 DRIZZLE_API
-void drizzle_remove_options(drizzle_st *drizzle, drizzle_options_t options);
+void drizzle_remove_options(drizzle_st *, drizzle_options_t);
 
 /**
  * Get application context pointer.

=== modified file 'libdrizzle-2.0/field.cc'
--- libdrizzle-2.0/field.cc	2011-11-04 21:06:16 +0000
+++ libdrizzle-2.0/field.cc	2011-11-18 16:11:02 +0000
@@ -77,13 +77,20 @@
 drizzle_field_t drizzle_field_buffer(drizzle_result_st *result, size_t *total,
                                      drizzle_return_t *ret_ptr)
 {
-  drizzle_field_t field;
   size_t offset= 0;
   size_t size= 0;
 
-  field= drizzle_field_read(result, &offset, &size, total, ret_ptr);
+  drizzle_return_t unused;
+  if (ret_ptr == NULL)
+  {
+    ret_ptr= &unused;
+  }
+
+  drizzle_field_t field= drizzle_field_read(result, &offset, &size, total, ret_ptr);
   if (*ret_ptr != DRIZZLE_RETURN_OK)
+  {
     return NULL;
+  }
 
   if (field == NULL)
   {
@@ -93,7 +100,14 @@
 
   if (result->field_buffer == NULL)
   {
-    result->field_buffer= new drizzle_field_t_type[(*total) + 1];
+    result->field_buffer= new (std::nothrow) drizzle_field_t_type[(*total) + 1];
+
+    if (result->field_buffer == NULL)
+    {
+      *ret_ptr= DRIZZLE_RETURN_MEMORY;
+      *total= 0;
+      return NULL;
+    }
   }
 
   memcpy(result->field_buffer + offset, field, size);
@@ -102,7 +116,9 @@
   {
     field= drizzle_field_read(result, &offset, &size, total, ret_ptr);
     if (*ret_ptr != DRIZZLE_RETURN_OK)
+    {
       return NULL;
+    }
 
     memcpy(result->field_buffer + offset, field, size);
   }

=== modified file 'libdrizzle-2.0/query.cc'
--- libdrizzle-2.0/query.cc	2011-11-18 02:03:41 +0000
+++ libdrizzle-2.0/query.cc	2011-11-18 16:11:02 +0000
@@ -54,12 +54,9 @@
                                      const char *query, 
                                      drizzle_return_t *ret_ptr)
 {
-  size_t size;
-
-  size= strlen(query);
-
-  return drizzle_con_command_write(con, result, DRIZZLE_COMMAND_QUERY,
-                                   (uint8_t *)query, size, size, ret_ptr);
+  size_t size= strlen(query);
+
+  return drizzle_con_command_write(con, result, DRIZZLE_COMMAND_QUERY, (uint8_t *)query, size, size, ret_ptr);
 }
 
 drizzle_result_st *drizzle_query_inc(drizzle_con_st *con,
@@ -67,8 +64,7 @@
                                      const char *query, size_t size,
                                      size_t total, drizzle_return_t *ret_ptr)
 {
-  return drizzle_con_command_write(con, result, DRIZZLE_COMMAND_QUERY,
-                                   (uint8_t *)query, size, total, ret_ptr);
+  return drizzle_con_command_write(con, result, DRIZZLE_COMMAND_QUERY, (uint8_t *)query, size, total, ret_ptr);
 }
 
 drizzle_query_st *drizzle_query_add(drizzle_st *drizzle,
@@ -79,9 +75,12 @@
                                     drizzle_query_options_t options,
                                     void *context)
 {
+  // @note drizzle_query_st handle the null drizzle case
   query= drizzle_query_create(drizzle, query);
   if (query == NULL)
+  {
     return NULL;
+  }
 
   drizzle_query_set_con(query, con);
   drizzle_query_set_result(query, result);
@@ -95,9 +94,19 @@
 drizzle_query_st *drizzle_query_create(drizzle_st *drizzle,
                                        drizzle_query_st *query)
 {
+  if (drizzle == NULL)
+  {
+    return NULL;
+  }
+
   if (query == NULL)
   {
-    query= new drizzle_query_st;
+    query= new (std::nothrow) drizzle_query_st;
+
+    if (query == NULL)
+    {
+      return NULL;
+    }
     query->options|= DRIZZLE_CON_ALLOCATED;
   }
   else
@@ -116,7 +125,9 @@
   query->drizzle= drizzle;
 
   if (drizzle->query_list)
+  {
     drizzle->query_list->prev= query;
+  }
   query->next= drizzle->query_list;
   drizzle->query_list= query;
   drizzle->query_count++;
@@ -127,15 +138,23 @@
 
 void drizzle_query_free(drizzle_query_st *query)
 {
+  if (query == NULL)
+  {
+    return;
+  }
+
   if (query->context != NULL && query->context_free_fn != NULL)
     query->context_free_fn(query, query->context);
 
   if (query->drizzle->query_list == query)
     query->drizzle->query_list= query->next;
+
   if (query->prev)
     query->prev->next= query->next;
+
   if (query->next)
     query->next->prev= query->prev;
+
   query->drizzle->query_count--;
 
   if (query->options & DRIZZLE_QUERY_ALLOCATED)
@@ -145,32 +164,59 @@
 void drizzle_query_free_all(drizzle_st *drizzle)
 {
   while (drizzle->query_list != NULL)
+  {
     drizzle_query_free(drizzle->query_list);
+  }
 }
 
 drizzle_con_st *drizzle_query_con(drizzle_query_st *query)
 {
+  if (query == NULL)
+  {
+    return NULL;
+  }
+
   return query->con;
 }
 
 void drizzle_query_set_con(drizzle_query_st *query, drizzle_con_st *con)
 {
+  if (query == NULL)
+  {
+    return;
+  }
+
   query->con= con;
 }
 
 drizzle_result_st *drizzle_query_result(drizzle_query_st *query)
 {
+  if (query == NULL)
+  {
+    return NULL;
+  }
+
   return query->result;
 }
 
 void drizzle_query_set_result(drizzle_query_st *query,
                               drizzle_result_st *result)
 {
+  if (query == NULL)
+  {
+    return;
+  }
+
   query->result= result;
 }
 
 char *drizzle_query_string(drizzle_query_st *query, size_t *size)
 {
+  if (query == NULL)
+  {
+    return NULL;
+  }
+
   *size= query->size;
   return (char *)(query->string);
 }
@@ -178,56 +224,102 @@
 void drizzle_query_set_string(drizzle_query_st *query, const char *string,
                               size_t size)
 {
+  if (query == NULL)
+  {
+    return;
+  }
+
   query->string= string;
   query->size= size;
 }
 
 int drizzle_query_options(drizzle_query_st *query)
 {
+  if (query == NULL)
+  {
+    return 0;
+  }
+
   return query->options;
 }
 
 void drizzle_query_set_options(drizzle_query_st *query,
                                int options)
 {
+  if (query == NULL)
+  {
+    return;
+  }
+
   query->options= options;
 }
 
 void drizzle_query_add_options(drizzle_query_st *query,
                                int options)
 {
+  if (query == NULL)
+  {
+    return;
+  }
+
   query->options|= options;
 }
 
 void drizzle_query_remove_options(drizzle_query_st *query,
                                   int options)
 {
+  if (query == NULL)
+  {
+    return;
+  }
+
   query->options&= ~options;
 }
 
 void *drizzle_query_context(drizzle_query_st *query)
 {
+  if (query == NULL)
+  {
+    return NULL;
+  }
+
   return query->context;
 }
 
 void drizzle_query_set_context(drizzle_query_st *query, void *context)
 {
+  if (query == NULL)
+  {
+    return;
+  }
+
   query->context= context;
 }
 
 void drizzle_query_set_context_free_fn(drizzle_query_st *query,
                                        drizzle_query_context_free_fn *function)
 {
+  if (query == NULL)
+  {
+    return;
+  }
+
   query->context_free_fn= function;
 }
 
 static void drizzle_query_run_state(drizzle_query_st* query,
                                     drizzle_return_t* ret_ptr)
 {
+  if (query == NULL)
+  {
+    return;
+  }
+
   switch (query->state)
   {
   case DRIZZLE_QUERY_STATE_INIT:
     query->state= DRIZZLE_QUERY_STATE_QUERY;
+
   case DRIZZLE_QUERY_STATE_QUERY:
     query->result= drizzle_query(query->con, query->result, query->string,
                                  query->size, ret_ptr);
@@ -262,9 +354,17 @@
 drizzle_query_st *drizzle_query_run(drizzle_st *drizzle,
                                     drizzle_return_t *ret_ptr)
 {
-  int options;
-  drizzle_query_st *query;
-  drizzle_con_st *con;
+  drizzle_return_t unused;
+  if (ret_ptr == NULL)
+  {
+    ret_ptr= &unused;
+  }
+
+  if (drizzle == NULL)
+  {
+    *ret_ptr= DRIZZLE_RETURN_INVALID_ARGUMENT;
+    return NULL;
+  }
 
   if (drizzle->query_new == 0 && drizzle->query_running == 0)
   {
@@ -272,16 +372,18 @@
     return NULL;
   }
 
-  options= drizzle->options;
-  drizzle->options|= DRIZZLE_NON_BLOCKING;
+  drizzle_st::options_t options= drizzle->options;
+  drizzle->options.is_non_blocking= false;
 
   /* Check to see if any queries need to be started. */
   if (drizzle->query_new > 0)
   {
-    for (query= drizzle->query_list; query != NULL; query= query->next)
+    for (drizzle_query_st *query= drizzle->query_list; query != NULL; query= query->next)
     {
       if (query->state != DRIZZLE_QUERY_STATE_INIT)
+      {
         continue;
+      }
 
       drizzle->query_new--;
       drizzle->query_running++;
@@ -307,10 +409,12 @@
 
   while (1)
   {
+    drizzle_con_st *con;
+
     /* Loop through each active connection. */
     while ((con= drizzle_con_ready(drizzle)) != NULL)
     {
-      query= con->query;
+      drizzle_query_st *query= con->query;
       drizzle_query_run_state(query, ret_ptr);
       if (query->state == DRIZZLE_QUERY_STATE_DONE)
       {
@@ -322,7 +426,7 @@
       assert(*ret_ptr == DRIZZLE_RETURN_IO_WAIT);
     }
 
-    if (options & DRIZZLE_NON_BLOCKING)
+    if (options.is_non_blocking)
     {
       *ret_ptr= DRIZZLE_RETURN_IO_WAIT;
       return NULL;
@@ -339,13 +443,20 @@
 
 drizzle_return_t drizzle_query_run_all(drizzle_st *drizzle)
 {
-  drizzle_return_t ret;
+  if (drizzle == NULL)
+  {
+    return DRIZZLE_RETURN_INVALID_ARGUMENT;
+  }
 
   while (drizzle->query_new > 0 || drizzle->query_running > 0)
   {
+    drizzle_return_t ret;
+
     (void)drizzle_query_run(drizzle, &ret);
     if (ret != DRIZZLE_RETURN_OK && ret != DRIZZLE_RETURN_ERROR_CODE)
+    {
       return ret;
+    }
   }
 
   return DRIZZLE_RETURN_OK;

=== modified file 'libdrizzle-2.0/result.cc'
--- libdrizzle-2.0/result.cc	2011-11-07 15:04:16 +0000
+++ libdrizzle-2.0/result.cc	2011-11-18 16:11:02 +0000
@@ -51,7 +51,13 @@
 {
   if (result == NULL)
   {
-    result= new drizzle_result_st;
+    result= new (std::nothrow) drizzle_result_st;
+
+    if (result == NULL)
+    {
+      return NULL;
+    }
+
     result->options|= DRIZZLE_RESULT_ALLOCATED;
   }
   else
@@ -328,14 +334,13 @@
     return DRIZZLE_RETURN_INVALID_ARGUMENT;
   }
 
-  drizzle_return_t ret;
-  drizzle_row_t row;
-
   if (!(result->options & DRIZZLE_RESULT_BUFFER_COLUMN))
   {
-    ret= drizzle_column_buffer(result);
+    drizzle_return_t ret= drizzle_column_buffer(result);
     if (ret != DRIZZLE_RETURN_OK)
+    {
       return ret;
+    }
   }
 
   if (result->column_count == 0)
@@ -346,22 +351,36 @@
 
   while (1)
   {
-    row= drizzle_row_buffer(result, &ret);
+    drizzle_return_t ret;
+    drizzle_row_t row= drizzle_row_buffer(result, &ret);
     if (ret != DRIZZLE_RETURN_OK)
+    {
       return ret;
+    }
 
     if (row == NULL)
+    {
       break;
+    }
 
     if (result->row_list == NULL)
     {
-      result->row_list= new drizzle_row_list_t;
+      result->row_list= new (std::nothrow) drizzle_row_list_t;
+
+      if (result->row_list == NULL)
+      {
+        return DRIZZLE_RETURN_MEMORY;
+      }
     }
 
 
     if (result->field_sizes_list == NULL)
     {
-      result->field_sizes_list= new drizzle_field_sizes_list_t;
+      result->field_sizes_list= new (std::nothrow) drizzle_field_sizes_list_t;
+
+      if (result->field_sizes_list == NULL)
+      {
+      }
     }
 
     result->row_list->push_back(row);
@@ -369,6 +388,7 @@
   }
 
   result->options|= DRIZZLE_RESULT_BUFFER_ROW;
+
   return DRIZZLE_RETURN_OK;
 }
 
@@ -426,22 +446,30 @@
     return;
   }
 
-  uint16_t x;
-
   result->con->packet_size= 0;
 
-  for (x= 0; x < result->column_count; x++)
+  for (uint16_t x= 0; x < result->column_count; x++)
   {
     if (field[x] == NULL)
+    {
       result->con->packet_size++;
+    }
     else if (size[x] < 251)
+    {
       result->con->packet_size+= (1 + size[x]);
+    }
     else if (size[x] < 65536)
+    {
       result->con->packet_size+= (3 + size[x]);
+    }
     else if (size[x] < 16777216)
+    {
       result->con->packet_size+= (4 + size[x]);
+    }
     else
+    {
       result->con->packet_size+= (9 + size[x]);
+    }
   }
 }
 
@@ -453,9 +481,13 @@
   }
 
   if (is_eof)
+  {
     result->options|= DRIZZLE_RESULT_EOF_PACKET;
+  }
   else
+  {
     result->options&= ~DRIZZLE_RESULT_EOF_PACKET;
+  }
 }
 
 void drizzle_result_set_info(drizzle_result_st *result, const char *info)
@@ -580,6 +612,7 @@
   if (con->buffer_size < con->packet_size)
   {
     drizzle_state_push(con, drizzle_state_read);
+
     return DRIZZLE_RETURN_OK;
   }
 
@@ -649,6 +682,7 @@
   }
 
   drizzle_state_pop(con);
+
   return ret;
 }
 
@@ -676,8 +710,8 @@
   /* Assume the entire result packet will fit in the buffer. */
   if ((con->packet_size + 4) > DRIZZLE_MAX_BUFFER_SIZE)
   {
-    drizzle_set_error(con->drizzle, "drizzle_state_result_write",
-                      "buffer too small:%zu", con->packet_size + 4);
+    drizzle_set_error(con->drizzle, "drizzle_state_result_write", "buffer too small:%zu", con->packet_size + 4);
+
     return DRIZZLE_RETURN_INTERNAL_ERROR;
   }
 
@@ -686,6 +720,7 @@
       con->packet_size)
   {
     drizzle_state_push(con, drizzle_state_write);
+
     return DRIZZLE_RETURN_OK;
   }
 
@@ -750,5 +785,6 @@
   drizzle_set_byte3(start, con->packet_size);
 
   drizzle_state_pop(con);
+
   return DRIZZLE_RETURN_OK;
 }

=== modified file 'libdrizzle-2.0/row.cc'
--- libdrizzle-2.0/row.cc	2011-11-04 21:06:16 +0000
+++ libdrizzle-2.0/row.cc	2011-11-18 16:11:02 +0000
@@ -69,23 +69,44 @@
                                  drizzle_return_t *ret_ptr)
 {
   size_t total;
-  drizzle_field_t field;
   drizzle_row_t row;
 
+  if (result == NULL)
+  {
+    return drizzle_row_t();
+  }
+
+  drizzle_return_t unused;
+  if (ret_ptr == NULL)
+  {
+    ret_ptr= &unused;
+  }
+
   if (result->row == NULL)
   {
     if (drizzle_row_read(result, ret_ptr) == 0 || *ret_ptr != DRIZZLE_RETURN_OK)
+    {
       return NULL;
-
-    result->row= new drizzle_row_t_type[result->column_count *2];
+    }
+
+    result->row= new (std::nothrow) drizzle_row_t_type[result->column_count *2];
+
+    if (result->row == NULL)
+    {
+      *ret_ptr= DRIZZLE_RETURN_MEMORY;
+      return drizzle_row_t();
+    }
     result->field_sizes= reinterpret_cast<size_t *>(result->row + result->column_count);
   }
 
   while (1)
   {
-    field= drizzle_field_buffer(result, &total, ret_ptr);
+    drizzle_field_t field= drizzle_field_buffer(result, &total, ret_ptr);
     if (*ret_ptr == DRIZZLE_RETURN_ROW_END)
+    {
       break;
+    }
+
     if (*ret_ptr != DRIZZLE_RETURN_OK)
     {
       if (*ret_ptr != DRIZZLE_RETURN_IO_WAIT)

=== modified file 'libdrizzle-2.0/structs.h'
--- libdrizzle-2.0/structs.h	2011-11-18 02:03:41 +0000
+++ libdrizzle-2.0/structs.h	2011-11-18 16:11:02 +0000
@@ -69,7 +69,19 @@
 {
 public:
   uint16_t error_code;
-  int options;
+  struct options_t {
+    bool is_allocated;
+    bool is_non_blocking;
+    bool is_free_objects;
+    bool is_assert_dangling;
+
+    options_t() :
+      is_allocated(false),
+      is_non_blocking(false),
+      is_free_objects(false),
+      is_assert_dangling(false)
+    { }
+  } options;
   drizzle_verbose_t verbose;
   uint32_t con_count;
   uint32_t pfds_size;
@@ -92,7 +104,7 @@
 
   drizzle_st() :
     error_code(0),
-    options(DRIZZLE_NONE),
+    options(),
     verbose(DRIZZLE_VERBOSE_ERROR),
     con_count(0),
     pfds_size(0),
@@ -228,6 +240,7 @@
  */
 class drizzle_query_st
 {
+private:
 public:
   drizzle_st *drizzle;
   drizzle_query_st *next;

